@@ -1,5 +1,5 @@
 /*
- * Fisoco, a FInding SOrting and COnverting free software
+ * Fisoco : FInd, Select, Order and COnvert files
  * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
@@ -53,13 +53,15 @@ private:
     int check_args (std::string command);
     void clean ();
     void display_version ();
+    const std::string currentDateTime ();
     void help ();
     void help (std::string argument);
+    void interactive_read ();
     void load ();
-    void load (std::string filename);
+    void load (int number);
     void info (int numbers);
     std::string prompt ();
-    void read ();
+    int read ();
     void search (std::string arg);
     int start_search (Glib::ustring search);
 
