@@ -1,5 +1,5 @@
 /*
- * Fisoco, a FInding SOrting and COnverting free software
+ * Fisoco : FInd, Select, Order and COnvert files
  * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
@@ -33,9 +33,13 @@
 #  include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 #include <iostream>
-#include <gtkmm.h>
+#include <list>
+#include <glibmm/ustring.h>
+// i18n
+#include "../include/gettext.h"
+
+using namespace std;
 
-class Gui;
 class Cli;
 
 class Search
@@ -44,27 +48,22 @@ public:
   Search ();
 
   // Thread function.
-  void do_work (Gui* caller, Glib::ustring search, std::string dir);
   void do_work_only (Cli* caller, Glib::ustring search, std::string dir);
   std::list<std::string>  getdir (Glib::ustring search, std::string dir);
   void stop_work ();
-  void recursive_search (std::list<std::string> results,
-			 Glib::ustring search,
-			 std::string dir,
-			 Gui* caller);
   void recursive_search_only (std::list<std::string> results,
-						 Glib::ustring search,
-						 std::string dir,
-						 Cli* caller);
-  bool has_stopped () const;
+                              Glib::ustring search,
+                              std::string dir,
+                              Cli* caller);
+  bool has_stopped ();
   std::list<std::string> extr_files (std::string search,
-				     std::list<std::string> rs, std::string dr);
+                                     std::list<std::string> rs, std::string dr);
   std::list<std::string> extr_dirs (std::list<std::string> rs, std::string dr);
   std::string get_type (std::string file, std::string dir);
-
+  
 private:
-  bool search_shall_stop;
-  bool search_has_stopped;
+    bool search_shall_stop;
+    bool search_has_stopped;
 };
 
 #endif // GTKMM_SEARCH_H
