@@ -1,5 +1,5 @@
 /*
- * Fisoco, a FInding SOrting and COnverting free software
+ * Fisoco : FInd, Select, Order and COnvert files
  * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
@@ -23,9 +23,10 @@
  *    ~~~~~~    *
  ****************/
 
+#include <algorithm>
+#include <sys/stat.h>
 #include "../include/cli.h"
 #include "../include/global.h"
-#include "../include/gui.h"
 #include "../include/search.h"
 
 Search::Search () :
@@ -37,45 +38,20 @@ Search::Search () :
 void
 Search::stop_work ()
 {
-    std::cout << gettext ("Stopping process...") << std::endl;
+    debug (gettext ("Stopping process..."));
     search_shall_stop = true;
 }
 
 bool
-Search::has_stopped () const
+Search::has_stopped ()
 {
-  return search_has_stopped;
-}
-
-void
-Search::do_work (Gui* caller, Glib::ustring search, std::string dir)
-{
-    if (search_shall_stop == false)
-    {
-        if (search.length () == 0)
-            caller->
-            error_dialog (gettext
-            ("No search keywords given !"));
-        std::list<std::string> results = getdir (search, dir);
-        if (results.size () == 0)
-            caller->
-            error_dialog (gettext
-            ("This directory doesn't exists or is unreadable..."));
-        else
-            recursive_search (results, search, dir, caller);
-    }
-    else
-    {
-        search_shall_stop = false;
-        search_has_stopped = true;
-    }
-    caller->notify ();
+    return search_has_stopped;
 }
 
 void
 Search::do_work_only (Cli* caller, Glib::ustring search, std::string dir)
 {
-    if (search_shall_stop == false)
+    if (!search_shall_stop)
     {
         if (search.length () == 0)
             error (gettext ("No search keywords given !"));
@@ -92,28 +68,6 @@ Search::do_work_only (Cli* caller, Glib::ustring search, std::string dir)
     }
 }
 
-void
-Search::recursive_search (std::list<std::string> results,
-                          Glib::ustring search, std::string dir, Gui* caller)
-{
-  std::list<std::string> files = extr_files (search, results, dir);
-  if (files.size () != 0)
-    {
-      caller->notify (files, dir);
-    }
-  std::list<std::string> directories = extr_dirs (results, dir);
-  if (directories.size() > 0 && !search_shall_stop)
-    {
-        for (std::list<std::string>::iterator d = directories.begin ();
-             d != directories.end (); ++d)
-             {
-                 std::string path = (dir != "/" ) ? (dir + "/" + *d) : (dir + *d);
-                 std::list<std::string> new_results  = getdir (search, path);
-                 recursive_search (new_results, search, path, caller);
-             }
-    }
-}
-
 void
 Search::recursive_search_only (std::list<std::string> results,
                                Glib::ustring search, std::string dir, Cli* caller)
@@ -143,13 +97,10 @@ Search::getdir (Glib::ustring search, std::string dir)
     DIR *dp;
     struct dirent *dirp;
     dir = (dir == "") ? "/" : dir;
-    if ((dp = opendir (dir.c_str ())) == NULL)
-        //    std::cout << gettext ("Error opening ") << dir << std::endl;
-        ;
-    else
-        while ((dirp = readdir (dp)) != NULL)
-            files.push_back (dirp->d_name);
-        closedir (dp);
+    if ((dp = opendir (dir.c_str ())) != NULL)
+      while ((dirp = readdir (dp)) != NULL)
+	files.push_back (dirp->d_name);
+    closedir (dp);
     return files;
 }
 
@@ -174,7 +125,8 @@ Search::extr_dirs (std::list<std::string> res, std::string pdir)
     for (std::list<std::string>::iterator dir = res.begin (); dir != res.end (); ++dir)
     {
         if ((dir->back() != '.') &&             // We need this for the moment, because
-            get_type(*dir, pdir) == "Directory" && *dir != "proc") // '/proc/*' contains a lot of junk
+            get_type(*dir, pdir) == "Directory" && *dir != "proc" && *dir != "sys") // '/proc/*' and '/sys/*'
+                                                // contains a lot of junk
             dirs.push_back (*dir);              // and we don't know how to manage it...
     }
     return dirs;
